.. mknapsack documentation master file, created by
   sphinx-quickstart on Thu Jul 21 23:07:08 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: readme.rst

.. toctree::
   :caption: Documentation
   :maxdepth: 2

   Getting started <readme.rst>


.. toctree::
   :caption: API
   :maxdepth: 4

   mknapsack
